Crate cherry_svm_decode

Crate cherry_svm_decode 

Structs

InstructionSignature
LogSignature
ParamInput
Represents a parameter input with a name and dynamic type

Enums

DynType
Represents a dynamic type that can be deserialized from binary data
DynValue
Represents a dynamically deserialized value

Functions

decode_instructions
decode_logs
deserialize_data
Deserializes binary data into a vector of dynamic values based on the provided parameter types
instruction_signature_to_arrow_schema
match_discriminators
svm_decode_instructions
svm_decode_logs